import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "projen", "0.65.51", __name__[0:-6], "projen@0.65.51.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
